/**
 * eobjects.org MetaModel
 * Copyright (C) 2010 eobjects.org
 *
 * This copyrighted material is made available to anyone wishing to use, modify,
 * copy, or redistribute it subject to the terms and conditions of the GNU
 * Lesser General Public License, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this distribution; if not, write to:
 * Free Software Foundation, Inc.
 * 51 Franklin Street, Fifth Floor
 * Boston, MA  02110-1301  USA
 */

package org.eobjects.metamodel.jdbc.dialects;

import org.eobjects.metamodel.jdbc.JdbcDataContext;
import org.eobjects.metamodel.query.Query;

public class MysqlQueryRewriter extends DefaultQueryRewriter implements IQueryRewriter {

    public MysqlQueryRewriter(JdbcDataContext dataContext) {
        super(dataContext);
    }

    @Override
    public boolean isFirstRowSupported() {
        return true;
    }

    @Override
    public boolean isMaxRowsSupported() {
        return true;
    }

    /**
     * If the Max rows and/or First row property of the query is set, then we
     * will use MySQLs LIMIT and OFFSET functions.
     */
    @Override
    public String rewriteQuery(Query query) {
        String queryString = super.rewriteQuery(query);
        final Integer maxRows = query.getMaxRows();
        if (maxRows != null) {
            queryString = queryString + " LIMIT " + maxRows;
        }

        final Integer firstRow = query.getFirstRow();
        if (firstRow != null) {
            queryString = queryString + " OFFSET " + firstRow;
        }

        return queryString;
    }

    @Override
    public String escapeQuotes(String filterItemOperand) {
        return filterItemOperand.replaceAll("\\'", "\\\\'");
    }
}